@@ -39,8 +39,8 @@ def main():
 
     parser = argparse.ArgumentParser(description='millConnect order creator.')
     parser.add_argument('projectPath', type=Path, help='The path to a project folder.')
-    parser.add_argument('--host', nargs='?', type=str, default='https://api.connect.millhouse.local/v1', help='The URL of the api.')
-    parser.add_argument('--uploadURL', nargs='?', type=str, default='https://connect.millhouse.local/uploadOrder', help='The URL to open in the browser.')
+    parser.add_argument('--host', nargs='?', type=str, default='https://api.connect.millhouse.de/v1', help='The URL of the api.')
+    parser.add_argument('--uploadURL', nargs='?', type=str, default='https://connect.millhouse.de/uploadOrder', help='The URL to open in the browser.')
 
     args = parser.parse_args()
     asyncio.run(run(projectPath=args.projectPath, host=args.host, uploadURL=args.uploadURL))
