@@ -225,6 +225,9 @@ class Project(object):
 
     def getPoints(self) -> List[Path]:
         return list(self._projectPath.glob('*.pts'))
+    
+    def getImplantDirectionFiles(self) -> List[Path]:
+        return list(self._projectPath.glob('ImplantDirectionPosition_*.xml'))
 
     def compressFiles(self, files: List[Path]) -> BytesIO:
         '''
